@@ -585,14 +585,14 @@ add_toolbar (GnomeApp * app, ConfManager * conf)
 			N_("Commit current transaction"),
 			sql_commit_trans_cb,
 			conf, NULL,
-			GNOME_APP_PIXMAP_STOCK, GTK_STOCK_APPLY,
+			GNOME_APP_PIXMAP_STOCK, GNOME_DB_STOCK_COMMIT,
 			0, 0, NULL},
 		{
 			GNOME_APP_UI_ITEM, N_("Rollback transaction"),
 			N_("Cancel current transaction"),
 			sql_rollback_trans_cb,
 			conf, NULL,
-			GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REVERT_TO_SAVED, NULL,
+			GNOME_APP_PIXMAP_STOCK, GNOME_DB_STOCK_ROLLBACK, NULL,
 			0, 0, NULL},
 		GNOMEUIINFO_SEPARATOR,
 		{
@@ -776,13 +776,13 @@ add_menus (GnomeApp * app, ConfManager * conf)
 			GNOME_APP_UI_ITEM, N_("Commit transaction"), N_("Commit current transaction"),
 			sql_commit_trans_cb,
 			conf, NULL,
-			GNOME_APP_PIXMAP_STOCK, GTK_STOCK_APPLY,
+			GNOME_APP_PIXMAP_STOCK, GNOME_DB_STOCK_COMMIT,
 			0, 0, NULL},
 		{
 			GNOME_APP_UI_ITEM, N_("Rollback transaction"), N_("Cancel current transaction"),
 			sql_rollback_trans_cb,
 			conf, NULL,
-			GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REVERT_TO_SAVED, NULL,
+			GNOME_APP_PIXMAP_STOCK, GNOME_DB_STOCK_ROLLBACK, NULL,
 			0, 0, NULL},
                 GNOMEUIINFO_END
         };
