@@ -224,10 +224,7 @@ sql_conn_close_cb (GtkWidget * widget, ConfManager * conf)
 	case 2: /* disconnect, no saving */
 		/* if we've got a pending transaction, ask the user what to do */
 		if (conf->current_transaction) {
-			if (gnome_db_yes_no_dialog (dialog,
-						    _("A transaction is pending. Would you like to "
-						      "commit the changes you did (select Yes) or "
-						      "discard them (select No)?"))) {
+			if (ask_commit_transaction (dialog)) {
 				gda_connection_commit_transaction (conf->srv->cnc, conf->current_transaction);
 			} else
 				gda_connection_rollback_transaction (conf->srv->cnc, conf->current_transaction);
@@ -1798,6 +1795,35 @@ file_saveas_dlg_ok_cb (GtkWidget * widget, GtkWidget *data)
 	conf->close_after_saving = FALSE;
 }
 
+static gboolean
+ask_commit_transaction (GtkWidget *dialog)
+{
+	GtkWidget *md, *image, *label, *box;
+	gboolean result;
+
+	md = gtk_dialog_new_with_buttons ("Transaction pending",
+					  GTK_WINDOW (dialog),
+					  GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					  GNOME_DB_STOCK_ROLLBACK, GTK_RESPONSE_CANCEL,
+					  GNOME_DB_STOCK_COMMIT, GTK_RESPONSE_OK, NULL);
+	gtk_dialog_set_default_response (GTK_DIALOG (md), GTK_RESPONSE_OK);
+
+	box = gnome_db_new_hbox_widget (FALSE, GNOME_PAD / 2);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (md)->vbox), box, TRUE, TRUE, GNOME_PAD / 2);
+	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_DIALOG);
+	gtk_widget_show (image);
+	gtk_box_pack_start (GTK_BOX (box), image, TRUE, TRUE, GNOME_PAD / 2);
+	label = gnome_db_new_label_widget (_("A transaction is pending. Would you like to\n"
+					     "commit the changes you did or discard them?"));
+	gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, GNOME_PAD / 2);
+
+	result = gtk_dialog_run (GTK_DIALOG (md)) == GTK_RESPONSE_OK;
+
+	gtk_widget_destroy (md);
+
+	return result;
+}
+
 void
 quit_cb (GtkWidget * widget, ConfManager * conf)
 {
@@ -1864,10 +1890,7 @@ quit_cb (GtkWidget * widget, ConfManager * conf)
 	case 2: /* just quit */
 		/* if we've got a pending transaction, ask the user what to do */
 		if (conf->current_transaction) {
-			if (gnome_db_yes_no_dialog (dialog,
-						    _("A transaction is pending. Would you like to "
-						      "commit the changes you did (select Yes) or "
-						      "discard them (select No)?"))) {
+			if (ask_commit_transaction (dialog)) {
 				gda_connection_commit_transaction (conf->srv->cnc, conf->current_transaction);
 			} else
 				gda_connection_rollback_transaction (conf->srv->cnc, conf->current_transaction);
