@@ -414,7 +414,7 @@ server_access_open_connect (ServerAccess * srv)
 	}
 
 	srv->cnc = gda_client_open_connection (GDA_CLIENT (srv), dsn->name,
-					       srv->user_name->str, srv->password->str);
+					       srv->user_name->str, srv->password->str, 0);
 
 	gda_config_free_data_source_info (dsn);
 	if (srv->cnc) { 
@@ -433,7 +433,7 @@ server_access_open_connect (ServerAccess * srv)
 		g_signal_emit (G_OBJECT (srv), server_access_signals[CONN_OPENED], 0);
 #ifdef debug_signal
 		g_print ("<< 'CONN_OPENED' from server_access_open_connect\n");
-#endif		
+#endif
 	}
 }
 
@@ -1065,8 +1065,7 @@ server_access_get_object_handler (ServerAccess * srv, GObject * obj)
 		   object, using the declared functions to bind objects */
 		list = srv->bindable_objects;
 		while (list && !dh) {
-			data = ((gpointer (*)(GObject *)) (list->data))
-				(obj);
+			data = ((gpointer (*)(GObject *)) (list->data))	(obj);
 			if (data) {
 				dh = g_hash_table_lookup (srv->types_objects_hash, data);
 
